# Getting started

This project runs on **python3**. Thus, python3 should be installed.

It is highly recommended installing the module via Python virtual environment.  
You can install and run this version. Issue the followings:

`pip install edam`

Above command installs `edam`, which will be available 
to the virtual environment. 

It also creates an `.edam` folder in your system's home directory. 
All EDAM related documents are located in this folder. 
User-drafted *template* and *metadata*, and *input* files should be placed 
under these corresponding directories. 

More information about the proposed workflow can be found 
in the [proposed-workflow](workflow.md#proposed-workflow). 